==> thx_job_import_export-0.0.8-py3-none-any.whl: thx/job_import_export/api/views.py <==
# -*- coding: utf-8 -*-
from django.core.exceptions import ImproperlyConfigured
from django.utils.translation import gettext_lazy as _

from rest_framework import status
from rest_framework.response import Response

from thx.job_import_export.utils import generate_filename, delete_private_file, write_private_file

__all__ = [
    'JobImportViewMixin',
    'JobImportViewSetMixin',
    'JobExportViewMixin',
    'JobExportViewSetMixin',
    'DownloadViewMixin',
    'DownloadViewSetMixin',
]


class _JobViewMixin:
    job_class = None

    def get_job_class(self):
        if not self.job_class:
            raise ImproperlyConfigured(
                _("%(class)s: `job_class` attribute must be defined." % {
                    "class": self.__class__.__name__
                })
            )
        return self.job_class


class _JobViewSetMixin:
    job_classes = {}

    def get_job_class(self):
        if not self.job_classes:
            raise ImproperlyConfigured(
                _("%(class)s: `job_classes` attribute must be defined." % {
                    "class": self.__class__.__name__
                })
            )
        if not isinstance(self.job_classes, dict):
            raise ImproperlyConfigured(
                _("%(class)s: `job_classes` attribute must be a dict." % {
                    "class": self.__class__.__name__
                })
            )
        try:
            return self.job_classes[self.action]
        except KeyError:
            raise ImproperlyConfigured(
                _("%(class)s: `job_classes` is not defined for action %(action)s." % {
                    "class": self.__class__.__name__,
                    "action": self.action,
                })
            )


class _JobImportViewMixin:
    def import_job(self, request, *args, **kwargs):
        serializer = self.get_serializer(data=request.data)
        if serializer.is_valid():
            parameters = serializer.get_parameters()
            filename = parameters.pop('filename')
            created, filename_or_error = write_private_file(
                owner=self.request.user,
                file_obj=filename
            )
            if created:
                parameters['filename'] = filename_or_error
                created, job_or_error = self.get_job_class().create(
                    creator=self.request.user,
                    parameters=parameters
                )
                if created:
                    return Response(
                        {_('job {} successfully created').format(job_or_error.pk)},
                        status=status.HTTP_201_CREATED
                    )
                else:
                    return Response(
                        {job_or_error},
                        status=status.HTTP_400_BAD_REQUEST,
                    )
            else:
                return Response(str(filename_or_error), status=status.HTTP_400_BAD_REQUEST)
        else:
            return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)


class _JobExportViewMixin:
    def export_job(self, request, *args, **kwargs):
        serializer = self.get_serializer(data=request.data)
        if serializer.is_valid():
            created, job_or_error = self.get_job_class().create(
                creator=self.request.user,
                parameters=serializer.get_parameters()
            )
            if created:
                return Response(
                    {_('job {} successfully created').format(job_or_error.pk)},
                    status=status.HTTP_201_CREATED
                )
            else:
                return Response(
                    str(job_or_error),
                    status=status.HTTP_400_BAD_REQUEST,
                )
        else:
            return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)


class _DownloadViewMixin:
    prefix_path = 'download'
    delete = True

    def get_prefix_path(self):
        """Hook this method for a custom `prefix_path`"""
        return self.prefix_path

    def download(self, request, *args, **kwargs):
        try:
            file_name = kwargs.get('file_name')
            filename = generate_filename(request.user, file_name, self.prefix_path)
            with open(filename, 'rb') as f:
                pdf_content = f.read()
            response = Response(pdf_content, content_type='application/pdf', status=status.HTTP_200_OK)
            response["Content-Disposition"] = f'attachment;filename="{file_name}"'
            if self.delete:
                delete_private_file(request.user, filename, self.prefix_path)
            return response
        except FileNotFoundError:
            return Response(_('File not found'), status=status.HTTP_404_NOT_FOUND)


# MAIN CLASSES
class JobImportViewMixin(_JobViewMixin, _JobImportViewMixin):
    """
    Example Usage:

    class JobImportView(JobImportViewMixin, GenericAPIView):
        job_class = jobs.SendImportJob
        serializer_class = serializers.SendImportJobSerializer

    or

    class JobImportView(JobImportViewMixin, GenericAPIView):
        job_class = jobs.ImportJob
        serializer_class = serializers.ImportJobSerializer
    """

    def post(self, request, *args, **kwargs):
        return self.import_job(request, *args, **kwargs)


class JobImportViewSetMixin(_JobViewSetMixin, _JobImportViewMixin):
    """
    Usage example:

    class MyViewSet(JobImportViewSetMixin, viewsets.ModelViewSet):

        job_classes = {
            'import_action1': jobs.ImportAction1Job,
            'import_action2': jobs.ImportAction2Job,
        }

        @action(methods=['post'], detail=False, url_path='import-action-1')
        def import_action1(self, request, *args, **kwargs):
            return super().import_job(request, *args, **kwargs)

        @action(methods=['post'], detail=False, url_path='import-action-2')
        def import_action2(self, request, *args, **kwargs):
            return super().import_job(request, *args, **kwargs)
    """


class JobExportViewMixin(_JobViewMixin, _JobExportViewMixin):
    """
    Example Usage:

    class JobExportView(JobExportViewMixin, GenericAPIView):
        job_class = jobs.SendExportJob
        serializer_class = serializers.SendExportJobSerializer

    or

    class JobExportView(JobExportViewMixin, GenericAPIView):
        job_class = jobs.ExportJob
        serializer_class = serializers.ExportJobSerializer
    """
    def post(self, request, *args, **kwargs):
        return self.export_job(request, *args, **kwargs)


class JobExportViewSetMixin(_JobViewSetMixin, _JobExportViewMixin):
    """
    Usage example:

    class MyViewSet(JobExportViewSetMixin, viewsets.ModelViewSet):

        job_classes = {
            'export_action1': jobs.ExportAction1Job,
            'export_action2': jobs.ExportAction2Job,
        }

        @action(methods=['post'], detail=False, url_path='export-action-1')
        def export_action1(self, request, *args, **kwargs):
            return super().export_job(request, *args, **kwargs)

        @action(methods=['post'], detail=False, url_path='export-action-2')
        def export_action2(self, request, *args, **kwargs):
            return super().export_job(request, *args, **kwargs)
    """


class DownloadViewMixin(_DownloadViewMixin):
    """
    Example Usage:

    class DownloadView(DownloadViewMixin, GenericAPIView):
        prefix_path = 'download'
        delete = True

    # urls.py
    urlpatterns += [
        re_path(
            r'download/(?P<file_name>[\w.]+)/',
            views.DownloadView.as_view(),
            name='download'
        ),
    ]
    """
    def get(self, request, *args, **kwargs):
        return self.download(request, *args, **kwargs)


class DownloadViewSetMixin(_DownloadViewMixin):
    """
    Usage example:

    class MyViewSet(DownloadViewSetMixin, viewsets.ModelViewSet):
        prefix_path = 'download'
        delete = True

        @action(methods=['get'], detail=False, url_path=r'download-action-1/(?P<file_name>[\w.]+)')
        def download_action1(self, request, *args, **kwargs):
            return super().download(request, *args, **kwargs)

        @action(methods=['get'], detail=False, url_path=r'download-action-2/(?P<file_name>[\w.]+)')
        def download_action2(self, request, *args, **kwargs):
            return super().download(request, *args, **kwargs)
    """

==> thx_job_import_export-0.1.1-py3-none-any.whl: thx/job_import_export/api/views.py <==
# -*- coding: utf-8 -*-
from django.core.exceptions import ImproperlyConfigured
from django.http import HttpResponse
from django.utils.translation import gettext_lazy as _
from rest_framework import status
from rest_framework.response import Response

from thx.job_import_export.utils import delete_private_file, generate_filename, write_private_file

__all__ = [
    'JobImportViewMixin',
    'JobImportViewSetMixin',
    'JobExportViewMixin',
    'JobExportViewSetMixin',
    'DownloadViewMixin',
    'DownloadViewSetMixin',
]


class _JobViewMixin:
    job_class = None

    def get_job_class(self):
        if not self.job_class:
            raise ImproperlyConfigured(
                _("%(class)s: `job_class` attribute must be defined." % {
                    "class": self.__class__.__name__
                })
            )
        return self.job_class


class _JobViewSetMixin:
    job_classes = {}

    def get_job_class(self):
        if not self.job_classes:
            raise ImproperlyConfigured(
                _("%(class)s: `job_classes` attribute must be defined." % {
                    "class": self.__class__.__name__
                })
            )
        if not isinstance(self.job_classes, dict):
            raise ImproperlyConfigured(
                _("%(class)s: `job_classes` attribute must be a dict." % {
                    "class": self.__class__.__name__
                })
            )
        try:
            return self.job_classes[self.action]
        except KeyError:
            raise ImproperlyConfigured(
                _("%(class)s: `job_classes` is not defined for action %(action)s." % {
                    "class": self.__class__.__name__,
                    "action": self.action,
                })
            )


class _JobImportViewMixin:
    def import_job(self, request, *args, **kwargs):
        serializer = self.get_serializer(data=request.data)
        if serializer.is_valid():
            parameters = serializer.get_parameters()
            filename = parameters.pop('filename')
            created, filename_or_error = write_private_file(
                owner=self.request.user,
                file_obj=filename
            )
            if created:
                parameters['filename'] = filename_or_error
                created, job_or_error = self.get_job_class().create(
                    creator=self.request.user,
                    parameters=parameters
                )
                if created:
                    return Response(
                        {_('job {} successfully created').format(job_or_error.pk)},
                        status=status.HTTP_201_CREATED
                    )
                else:
                    return Response(
                        {job_or_error},
                        status=status.HTTP_400_BAD_REQUEST,
                    )
            else:
                return Response(str(filename_or_error), status=status.HTTP_400_BAD_REQUEST)
        else:
            return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)


class _JobExportViewMixin:
    def export_job(self, request, *args, **kwargs):
        serializer = self.get_serializer(data=request.data)
        if serializer.is_valid():
            created, job_or_error = self.get_job_class().create(
                creator=self.request.user,
                parameters=serializer.get_parameters()
            )
            if created:
                return Response(
                    {_('job {} successfully created').format(job_or_error.pk)},
                    status=status.HTTP_201_CREATED
                )
            else:
                return Response(
                    str(job_or_error),
                    status=status.HTTP_400_BAD_REQUEST,
                )
        else:
            return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)


class _DownloadViewMixin:
    prefix_path = 'download'
    delete = True

    def get_prefix_path(self):
        """Hook this method for a custom `prefix_path`"""
        return self.prefix_path

    def download(self, request, content_type='application/pdf', *args, **kwargs):
        try:
            file_name = kwargs.get('file_name')
            filename = generate_filename(request.user, file_name, self.prefix_path)
            with open(filename, 'rb') as f:
                file_content = f.read()
            response = HttpResponse(file_content, content_type=content_type, status=status.HTTP_200_OK)
            response["Content-Disposition"] = f'attachment;filename="{file_name}"'
            if self.delete:
                delete_private_file(request.user, filename, self.prefix_path)
            return response
        except FileNotFoundError:
            return Response(_('File not found'), status=status.HTTP_404_NOT_FOUND)


# MAIN CLASSES
class JobImportViewMixin(_JobViewMixin, _JobImportViewMixin):
    """
    Example Usage:

    class JobImportView(JobImportViewMixin, GenericAPIView):
        job_class = jobs.SendImportJob
        serializer_class = serializers.SendImportJobSerializer

    or

    class JobImportView(JobImportViewMixin, GenericAPIView):
        job_class = jobs.ImportJob
        serializer_class = serializers.ImportJobSerializer
    """

    def post(self, request, *args, **kwargs):
        return self.import_job(request, *args, **kwargs)


class JobImportViewSetMixin(_JobViewSetMixin, _JobImportViewMixin):
    """
    Usage example:

    class MyViewSet(JobImportViewSetMixin, viewsets.ModelViewSet):

        job_classes = {
            'import_action1': jobs.ImportAction1Job,
            'import_action2': jobs.ImportAction2Job,
        }

        @action(methods=['post'], detail=False, url_path='import-action-1')
        def import_action1(self, request, *args, **kwargs):
            return super().import_job(request, *args, **kwargs)

        @action(methods=['post'], detail=False, url_path='import-action-2')
        def import_action2(self, request, *args, **kwargs):
            return super().import_job(request, *args, **kwargs)
    """


class JobExportViewMixin(_JobViewMixin, _JobExportViewMixin):
    """
    Example Usage:

    class JobExportView(JobExportViewMixin, GenericAPIView):
        job_class = jobs.SendExportJob
        serializer_class = serializers.SendExportJobSerializer

    or

    class JobExportView(JobExportViewMixin, GenericAPIView):
        job_class = jobs.ExportJob
        serializer_class = serializers.ExportJobSerializer
    """
    def post(self, request, *args, **kwargs):
        return self.export_job(request, *args, **kwargs)


class JobExportViewSetMixin(_JobViewSetMixin, _JobExportViewMixin):
    """
    Usage example:

    class MyViewSet(JobExportViewSetMixin, viewsets.ModelViewSet):

        job_classes = {
            'export_action1': jobs.ExportAction1Job,
            'export_action2': jobs.ExportAction2Job,
        }

        @action(methods=['post'], detail=False, url_path='export-action-1')
        def export_action1(self, request, *args, **kwargs):
            return super().export_job(request, *args, **kwargs)

        @action(methods=['post'], detail=False, url_path='export-action-2')
        def export_action2(self, request, *args, **kwargs):
            return super().export_job(request, *args, **kwargs)
    """


class DownloadViewMixin(_DownloadViewMixin):
    """
    Example Usage:

    class DownloadView(DownloadViewMixin, GenericAPIView):
        prefix_path = 'download'
        delete = True

    # urls.py
    urlpatterns += [
        re_path(
            r'download/(?P<file_name>[\w.]+)/',
            views.DownloadView.as_view(),
            name='download'
        ),
    ]
    """
    def get(self, request, *args, **kwargs):
        return self.download(request, *args, **kwargs)


class DownloadViewSetMixin(_DownloadViewMixin):
    """
    Usage example:

    class MyViewSet(DownloadViewSetMixin, viewsets.ModelViewSet):
        prefix_path = 'download'
        delete = True

        @action(methods=['get'], detail=False, url_path=r'download-action-1/(?P<file_name>[\w.]+)')
        def download_action1(self, request, *args, **kwargs):
            return super().download(request, *args, **kwargs)

        @action(methods=['get'], detail=False, url_path=r'download-action-2/(?P<file_name>[\w.]+)')
        def download_action2(self, request, *args, **kwargs):
            return super().download(request, *args, **kwargs)
    """
